run

Function run 

pub async fn run(args: &mut GithubActionArgs) -> Result<bool>
Run lintel checks and post results as a GitHub Check Run.

Reads GITHUB_TOKEN, GITHUB_REPOSITORY, GITHUB_SHA, and (optionally) GITHUB_API_URL from the environment.

Returns Ok(true) if errors were found, Ok(false) if clean.

Errors

Returns an error if environment variables are missing, validation fails to run, or the GitHub Checks API request fails.